( cd usr/lib ; rm -rf libmetamail.so.0 )
( cd usr/lib ; ln -sf libmetamail.so.0.0.0 libmetamail.so.0 )
( cd usr/lib ; rm -rf libmetamail.so )
( cd usr/lib ; ln -sf libmetamail.so.0.0.0 libmetamail.so )
