#ifndef COMMON_ERROR_H
#define COMMON_ERROR_H 1
      
#include <metamail/common.h>

BEGIN_C_DECLS
      
extern const char *program_name;
extern void set_program_name PARAMS((const char *argv0));
      
extern void metamail_warning      PARAMS((const char *message, ...));
extern void metamail_error        PARAMS((const char *message, ...));
extern void metamail_fatal        PARAMS((const char *message, ...));
      
END_C_DECLS
      
#endif /* !COMMON_ERROR_H */
